@@ -1,7 +1,7 @@
 package Perl::Critic::Policy::Variables::ProhibitLoopOnHash;
 our $AUTHORITY = 'cpan:XSAWYERX';
 # ABSTRACT: Don't write loops on hashes, only on keys and values of hashes
-$Perl::Critic::Policy::Variables::ProhibitLoopOnHash::VERSION = '0.002';
+$Perl::Critic::Policy::Variables::ProhibitLoopOnHash::VERSION = '0.003';
 use strict;
 use warnings;
 use parent 'Perl::Critic::Policy';
@@ -115,7 +115,7 @@ Perl::Critic::Policy::Variables::ProhibitLoopOnHash - Don't write loops on hashe
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
@@ -129,8 +129,11 @@ you forgot to call C<keys> or C<values> you will accidentally loop over both.
 
 An effort is made to detect expressions:
 
-    action() for %hash ? keys %hash : ();                        # ok
-    action() for %{ keys $hash{'stuff'} ? $hash{'stuff'} : {} }; # ok
+    action() for %hash ? keys %hash : ();                             # ok
+    action() for %{ $hash{'stuff'} } ? keys %{ $hash{'stuff'} } : (); # ok
+
+(Granted, the second example there doesn't make much sense, but I have found
+a variationo of it in real code.)
 
 =head1 CONFIGURATION
 
